@@ -2,7 +2,7 @@
 /*!	\file metaballs.h
 **	\brief Header file for implementation of the "Metaballs" layer
 **
-**	$Id: metaballs.h 1192 2007-12-10 02:01:25Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -28,7 +28,7 @@
 /* === H E A D E R S ======================================================= */
 
 #include <synfig/layer_composite.h>
-#include <synfig/color.h>
+#include <synfig/gradient.h>
 #include <synfig/vector.h>
 #include <synfig/value.h>
 #include <vector>
@@ -44,14 +44,18 @@ class Metaballs : public synfig::Layer_Composite
 
 private:
 
-	synfig::Color color;
+	synfig::Gradient gradient;
 
 	std::vector<synfig::Point>	centers;
 	std::vector<synfig::Real>	radii;
 	std::vector<synfig::Real>	weights;
 
 	synfig::Real	threshold;
-	//Real	threshold2;
+	synfig::Real	threshold2;
+
+	bool positive;
+
+	synfig::Real densityfunc(const synfig::Point &p, const synfig::Point &c, synfig::Real R)const;
 
 	synfig::Real totaldensity(const synfig::Point &pos)const;
 
@@ -68,6 +72,8 @@ public:
 	virtual bool accelerated_render(synfig::Context context,synfig::Surface *surface,int quality, const synfig::RendDesc &renddesc, synfig::ProgressCallback *cb)const;
 
 	virtual Vocab get_param_vocab()const;
+
+	virtual synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
 }; // END of class Metaballs
 
 /* === E N D =============================================================== */
