@@ -2,7 +2,7 @@
 /*!	\file simplecircle.cpp
 **	\brief Implementation of the "Simple Circle" layer
 **
-**	$Id: simplecircle.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -54,9 +54,9 @@ using namespace synfig;
 SYNFIG_LAYER_INIT(SimpleCircle);
 SYNFIG_LAYER_SET_NAME(SimpleCircle,"simple_circle");
 SYNFIG_LAYER_SET_LOCAL_NAME(SimpleCircle,N_("Simple Circle"));
-SYNFIG_LAYER_SET_CATEGORY(SimpleCircle,CATEGORY_DO_NOT_USE);
+SYNFIG_LAYER_SET_CATEGORY(SimpleCircle,N_("Example"));
 SYNFIG_LAYER_SET_VERSION(SimpleCircle,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(SimpleCircle,"$Id: simplecircle.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(SimpleCircle,"$Id$");
 
 /* === P R O C E D U R E S ================================================= */
 
