@@ -2,7 +2,7 @@
 /*!	\file insideout.cpp
 **	\brief Implementation of the "Inside Out" layer
 **
-**	$Id: insideout.cpp 1191 2007-12-10 01:58:46Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -55,7 +55,7 @@ SYNFIG_LAYER_SET_NAME(InsideOut,"inside_out");
 SYNFIG_LAYER_SET_LOCAL_NAME(InsideOut,N_("Inside Out"));
 SYNFIG_LAYER_SET_CATEGORY(InsideOut,N_("Distortions"));
 SYNFIG_LAYER_SET_VERSION(InsideOut,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(InsideOut,"$Id: insideout.cpp 1191 2007-12-10 01:58:46Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(InsideOut,"$Id$");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -106,7 +106,7 @@ class InsideOut_Trans : public Transform
 {
 	etl::handle<const InsideOut> layer;
 public:
-	InsideOut_Trans(const InsideOut* x):layer(x) { }
+	InsideOut_Trans(const InsideOut* x):Transform(x->get_guid()),layer(x) { }
 
 	synfig::Vector perform(const synfig::Vector& x)const
 	{
