@@ -2,7 +2,7 @@
 /*!	\file mptr_ffmpeg.cpp
 **	\brief ppm Target Module
 **
-**	$Id: mptr_ffmpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -73,10 +73,15 @@ SYNFIG_IMPORTER_INIT(ffmpeg_mptr);
 SYNFIG_IMPORTER_SET_NAME(ffmpeg_mptr,"ffmpeg");
 SYNFIG_IMPORTER_SET_EXT(ffmpeg_mptr,"avi");
 SYNFIG_IMPORTER_SET_VERSION(ffmpeg_mptr,"0.1");
-SYNFIG_IMPORTER_SET_CVS_ID(ffmpeg_mptr,"$Id: mptr_ffmpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $");
+SYNFIG_IMPORTER_SET_CVS_ID(ffmpeg_mptr,"$Id$");
 
 /* === M E T H O D S ======================================================= */
 
+bool ffmpeg_mptr::is_animated()
+{
+	return true;
+}
+
 bool
 ffmpeg_mptr::seek_to(int frame)
 {
@@ -96,27 +101,27 @@ ffmpeg_mptr::seek_to(int frame)
 #if defined(WIN32_PIPE_TO_PROCESSES)
 
 		string command;
-		
-		command=strprintf("ffmpeg -i \"%s\" -an -f image2pipe -vcodec ppm -\n",filename.c_str());
-		
+
+		command=strprintf("ffmpeg -ss 00:00:00.%d -i \"%s\" -an -f image2pipe -vcodec ppm -\n",frame,filename.c_str());
+
 		file=popen(command.c_str(),POPEN_BINARY_READ_TYPE);
 
 #elif defined(UNIX_PIPE_TO_PROCESSES)
 
 		int p[2];
-	  
+
 		if (pipe(p)) {
 			cerr<<"Unable to open pipe to ffmpeg"<<endl;
 			return false;
 		};
-	  
+
 		pid = fork();
-	  
+
 		if (pid == -1) {
 			cerr<<"Unable to open pipe to ffmpeg"<<endl;
 			return false;
 		}
-	  
+
 		if (pid == 0){
 			// Child process
 			// Close pipein, not needed
@@ -128,10 +133,11 @@ ffmpeg_mptr::seek_to(int frame)
 			}
 			// Close the unneeded pipein
 			close(p[1]);
-			execlp("ffmpeg", "ffmpeg", "-i", filename.c_str(), "-an", "-f", "image2pipe", "-vcodec", "ppm", "-", (const char *)NULL);
+			string time = strprintf("00:00:00.%d",frame);
+			execlp("ffmpeg", "ffmpeg", "-ss", time.c_str(), "-i", filename.c_str(), "-an", "-f", "image2pipe", "-vcodec", "ppm", "-", (const char *)NULL);
 			// We should never reach here unless the exec failed
 			cerr<<"Unable to open pipe to ffmpeg"<<endl;
-			return false;
+			_exit(1);
 		} else {
 			// Parent process
 			// Close pipeout, not needed
@@ -173,6 +179,10 @@ ffmpeg_mptr::grab_frame(void)
 	float divisor;
 	char cookie[2];
 	cookie[0]=fgetc(file);
+
+	if(feof(file))
+		return false;
+
 	cookie[1]=fgetc(file);
 
 	if(cookie[0]!='P' || cookie[1]!='6')
@@ -260,5 +270,5 @@ ffmpeg_mptr::get_frame(synfig::Surface &surface,Time time, synfig::ProgressCallb
 	}
 
 	surface=frame;
-	return false;
+	return true;
 }
