@@ -2,7 +2,7 @@
 /*!	\file distort.h
 **	\brief Header file for implementation of the "Noise Distort" layer
 **
-**	$Id: distort.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,7 +33,7 @@
 #include <synfig/layer_composite.h>
 #include <synfig/gradient.h>
 #include <synfig/time.h>
-#include "random.h"
+#include "random_noise.h"
 
 /* === M A C R O S ========================================================= */
 
@@ -49,8 +49,8 @@ private:
 
 	synfig::Vector size;
 
-	Random random;
-	Random::SmoothType smooth;
+	RandomNoise random;
+	RandomNoise::SmoothType smooth;
 	int detail;
 	synfig::Real speed;
 	bool turbulent;
