@@ -2,7 +2,7 @@
 /*!	\file canvas.h
 **	\brief Canvas Class Implementation
 **
-**	$Id: canvas.h 2067 2008-09-23 17:47:09Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -97,9 +97,13 @@
  *      Added "scale" link to the "BLine Width" ValueNode in svn r1872.
  *
  *      Added "loop" link to the "Gradient Color" ValueNode in svn r1901.
+ *
+ * 0.7: svn r2315
+ *
+ *      Added "loop" link to the "Random" ValueNode in svn r2315.
  */
 
-#define CURRENT_CANVAS_VERSION "0.6"
+#define CURRENT_CANVAS_VERSION "0.7"
 
 /* === T Y P E D E F S ===================================================== */
 
@@ -469,19 +473,19 @@ public:
 	**		If not found, it creates a new Canvas and returns it
 	**		If an error occurs, it returns an empty handle
 	*/
-	Handle surefind_canvas(const String &id);
+	Handle surefind_canvas(const String &id,String &warnings);
 
 	//! Finds a child Canvas in the Canvas with the given \a id
 	/*!	\return If found, returns a handle to the child Canvas.
 	**		Otherwise, returns an empty handle.
 	*/
-	Handle find_canvas(const String &id);
+	Handle find_canvas(const String &id, String &warnings);
 
 	//! Finds a child Canvas in the Canvas with the given \a id
 	/*!	\return If found, returns a handle to the child Canvas.
 	**		Otherwise, returns an empty handle.
 	*/
-	ConstHandle find_canvas(const String &id)const;
+	ConstHandle find_canvas(const String &id, String &warnings)const;
 
 	//! Sets the file path for the Canvas
 	//void set_file_path(const String &);
@@ -541,6 +545,12 @@ public:
 
 	Handle clone(const GUID& deriv_guid=GUID())const;
 
+	void register_external_canvas(String file, Handle canvas);
+
+#ifdef _DEBUG
+	void show_externals(String file, int line, String text) const;
+#endif	// _DEBUG
+
 private:
 	void add_group_pair(String group, etl::handle<Layer> layer);
 	void remove_group_pair(String group, etl::handle<Layer> layer);
