@@ -2,7 +2,7 @@
 /*!	\file gradient.cpp
 **	\brief Color Gradient Class Member Definitions
 **
-**	$Id: gradient.cpp 1463 2008-01-25 12:29:39Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -203,7 +203,7 @@ synfig::Gradient::operator+=(const Gradient &rhs)
 				// otherwise we sum the first in each, and the last in each
 				else
 				{
-					if (print) printf("[copying %d from left %d and %d from right %d at %.2f]\n", iter1-left_same+1, tpos1, iter2-right_same+1, tpos2, left.pos);
+					if (print) printf("[copying %ld from left %d and %ld from right %d at %.2f]\n", iter1-left_same+1, tpos1, iter2-right_same+1, tpos2, left.pos);
 					// merge the front two cpoints
 					if (print) printf("  copy front from left %d right %d\n", tpos1++, tpos2++);
 					ret.push_back(CPoint(left.pos, left.color + right.color));
