@@ -1,8 +1,9 @@
+#include <cstdio>
 /* === S Y N F I G ========================================================= */
 /*!	\file importer.h
 **	\brief writeme
 **
-**	$Id: importer.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -108,6 +109,13 @@ public:
 	**	\see ProgressCallback, Surface
 	*/
 	virtual bool get_frame(Surface &surface,Time time, ProgressCallback *callback=NULL)=0;
+	virtual bool get_frame(Surface &surface,Time time,
+						   bool &trimmed __attribute__ ((unused)),
+						   unsigned int &width __attribute__ ((unused)), unsigned int &height __attribute__ ((unused)),
+						   unsigned int &top __attribute__ ((unused)), unsigned int &left __attribute__ ((unused)),
+						   ProgressCallback *callback=NULL) {
+		return get_frame(surface,time,callback);
+	}
 
 	//! Returns \c true if the importer pays attention to the \a time parameter of get_frame()
 	virtual bool is_animated() { return false; }
