@@ -2,7 +2,7 @@
 /*!	\file layer.h
 **	\brief Layer Class Header
 **
-**	$Id: layer.h 1648 2008-02-10 09:13:54Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -482,10 +482,8 @@ public:
 	**  context until the final blend operation. */
 	virtual bool reads_context()const;
 
-#ifdef THIS_CODE_IS_NOT_USED
 	//! Duplicates the Layer without duplicating the value nodes
-	virtual Layer *simple_clone()const;
-#endif /* THIS_CODE_IS_NOT_USED */
+	virtual Handle simple_clone()const;
 
 protected:
 
