@@ -2,7 +2,7 @@
 /*!	\file layer_pastecanvas.cpp
 **	\brief Implementation of the "Paste Canvas" layer
 **
-**	$Id: layer_pastecanvas.cpp 2060 2008-09-19 16:13:02Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -77,12 +77,13 @@ SYNFIG_LAYER_SET_NAME(Layer_PasteCanvas,"PasteCanvas"); // todo: use paste_canva
 SYNFIG_LAYER_SET_LOCAL_NAME(Layer_PasteCanvas,N_("Paste Canvas"));
 SYNFIG_LAYER_SET_CATEGORY(Layer_PasteCanvas,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(Layer_PasteCanvas,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_PasteCanvas,"$Id: layer_pastecanvas.cpp 2060 2008-09-19 16:13:02Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_PasteCanvas,"$Id$");
 
 /* === M E T H O D S ======================================================= */
 
 Layer_PasteCanvas::Layer_PasteCanvas():
 	origin(0,0),
+	focus(0,0),
 	depth(0),
 	zoom(0),
 	time_offset(0),
@@ -144,6 +145,14 @@ Layer_PasteCanvas::get_param_vocab()const
 		.set_local_name(_("Children Lock"))
 	);
 
+	ret.push_back(ParamDesc("focus")
+		.set_local_name(_("Focus Point"))
+		.set_origin("origin")
+		.set_connect("origin")
+		.set_description(_("Point to remain fixed when zooming"))
+	//	.set_invisible_duck()
+	);
+
 	// optimize_layers() in canvas.cpp makes a new PasteCanvas layer
 	// and copies over the parameters of the old layer.  the
 	// 'curr_time' member wasn't being copied, so I've added it as a
@@ -163,6 +172,7 @@ bool
 Layer_PasteCanvas::set_param(const String & param, const ValueBase &value)
 {
 	IMPORT(origin);
+	IMPORT(focus);
 
 	// IMPORT(canvas);
 	if(param=="canvas" && value.same_type_as(Canvas::Handle()))
@@ -212,6 +222,8 @@ Layer_PasteCanvas::set_sub_canvas(etl::handle<synfig::Canvas> x)
 
 	child_changed_connection.disconnect();
 
+	if (canvas != x) signal_subcanvas_changed()();
+
 	canvas=x;
 
 	/*if(canvas)
@@ -223,8 +235,7 @@ Layer_PasteCanvas::set_sub_canvas(etl::handle<synfig::Canvas> x)
 		);
 	*/
 	if(canvas)
-		bounds = ((canvas->get_context().get_full_bounding_rect() - canvas->rend_desc().get_focus()) * exp(zoom) +
-				  origin + canvas->rend_desc().get_focus());
+		bounds = ((canvas->get_context().get_full_bounding_rect() - focus) * exp(zoom) + origin + focus);
 
 	if(canvas && muck_with_time_)
 		add_child(canvas.get());
@@ -241,6 +252,24 @@ Layer_PasteCanvas::set_sub_canvas(etl::handle<synfig::Canvas> x)
 		on_canvas_set();
 }
 
+// when a pastecanvas that contains another pastecanvas is copy/pasted
+// from one document to another, only the outermost pastecanvas was
+// getting its renddesc set to match that of its new parent.  this
+// function is used to recurse through the pastecanvas copying its
+// renddesc to any pastecanvases it contains (bug #2116947, svn r2200)
+void
+Layer_PasteCanvas::update_renddesc()
+{
+	if(!get_canvas() || !canvas || !canvas->is_inline()) return;
+
+	canvas->rend_desc()=get_canvas()->rend_desc();
+	for (Context context = canvas->get_context(); !context->empty(); context++)
+	{
+		etl::handle<Layer_PasteCanvas> paste = etl::handle<Layer_PasteCanvas>::cast_dynamic(*context);
+		if (paste) paste->update_renddesc();
+	}
+}
+
 // This is called whenever the parent canvas gets set/changed
 void
 Layer_PasteCanvas::on_canvas_set()
@@ -258,6 +287,7 @@ ValueBase
 Layer_PasteCanvas::get_param(const String& param)const
 {
 	EXPORT(origin);
+	EXPORT(focus);
 	EXPORT(canvas);
 	EXPORT(zoom);
 	EXPORT(time_offset);
@@ -281,7 +311,7 @@ Layer_PasteCanvas::set_time(Context context, Time time)const
 	{
 		canvas->set_time(time+time_offset);
 
-		bounds=(canvas->get_context().get_full_bounding_rect()-canvas->rend_desc().get_focus())*exp(zoom)+origin+canvas->rend_desc().get_focus();
+		bounds=(canvas->get_context().get_full_bounding_rect()-focus)*exp(zoom)+origin+focus;
 	}
 	else
 		bounds=Rect::zero();
@@ -293,7 +323,7 @@ Layer_PasteCanvas::hit_check(synfig::Context context, const synfig::Point &pos)c
 	if(depth==MAX_DEPTH)return 0;depth_counter counter(depth);
 
 	if (canvas) {
-		Point target_pos=(pos-canvas->rend_desc().get_focus()-origin)/exp(zoom)+canvas->rend_desc().get_focus();
+		Point target_pos=(pos-focus-origin)/exp(zoom)+focus;
 
 		if(canvas && get_amount() && canvas->get_context().get_color(target_pos).get_a()>=0.25)
 		{
@@ -315,7 +345,7 @@ Layer_PasteCanvas::get_color(Context context, const Point &pos)const
 
 	if(depth==MAX_DEPTH)return Color::alpha();depth_counter counter(depth);
 
-	Point target_pos=(pos-canvas->rend_desc().get_focus()-origin)/exp(zoom)+canvas->rend_desc().get_focus();
+	Point target_pos=(pos-focus-origin)/exp(zoom)+focus;
 
 	return Color::blend(canvas->get_context().get_color(target_pos),context.get_color(pos),get_amount(),get_blend_method());
 }
@@ -343,8 +373,8 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 	RendDesc desc(renddesc);
 	Vector::value_type zoomfactor=1.0/exp(zoom);
 	desc.clear_flags();
-	desc.set_tl((desc.get_tl()-canvas->rend_desc().get_focus()-origin)*zoomfactor+canvas->rend_desc().get_focus());
-	desc.set_br((desc.get_br()-canvas->rend_desc().get_focus()-origin)*zoomfactor+canvas->rend_desc().get_focus());
+	desc.set_tl((desc.get_tl()-focus-origin)*zoomfactor+focus);
+	desc.set_br((desc.get_br()-focus-origin)*zoomfactor+focus);
 	desc.set_flags(RendDesc::PX_ASPECT);
 
 	if (is_solid_color() || context->empty())
@@ -393,7 +423,7 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 		if (blend_method==Color::BLEND_COMPOSITE) blend_using_straight = true;
 	}
 
-	if (!etl::intersect(context.get_full_bounding_rect(),full_bounding_rect+origin))
+	if (!etl::intersect(context.get_full_bounding_rect(),(full_bounding_rect-focus)*exp(zoom)+origin+focus))
 	{
 		// if there's no intersection between the context and our
 		// surface, and we're rendering 'onto', then we're done
