@@ -2,7 +2,7 @@
 /*!	\file layer_pastecanvas.h
 **	\brief Header file for implementation of the "Paste Canvas" layer
 **
-**	$Id: layer_pastecanvas.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,6 +51,7 @@ class Layer_PasteCanvas : public Layer_Composite, public Layer_NoDeform
 private:
 
 	Vector origin;
+	Vector focus;
 
 	etl::loose_handle<synfig::Canvas> canvas;
 
@@ -97,8 +98,27 @@ private:
 	// did, but we've forgotten whether we did.  So we use this
 	// 'extra_reference' member to store that decision.
 	bool extra_reference;
+
+	/*
+ -- ** -- S I G N A L S -------------------------------------------------------
+	*/
+
+private:
+
+	sigc::signal<void> signal_subcanvas_changed_;
+
+	/*
+ -- ** -- S I G N A L   I N T E R F A C E -------------------------------------
+	*/
+
 public:
 
+	sigc::signal<void>& signal_subcanvas_changed() { return signal_subcanvas_changed_; }
+
+public:
+
+	void update_renddesc();
+
 	virtual void on_canvas_set();
 
 	void set_muck_with_time(bool x=false) { muck_with_time_=x; }
