@@ -2,7 +2,7 @@
 /*!	\file synfig/module.h
 **	\brief writeme
 **
-**	$Id: module.h 1649 2008-02-10 09:14:08Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -182,7 +182,7 @@ public:
 
 	static bool subsys_init(const String &prefix);
 	static bool subsys_stop();
-	static bool register_default_modules();
+	static void register_default_modules(ProgressCallback *cb=NULL);
 
 	static void Register(Handle mod);
 	static bool Register(const String &module_name, ProgressCallback *cb=NULL);
