@@ -2,7 +2,7 @@
 /*!	\file node.cpp
 **	\brief Template File
 **
-**	$Id: node.cpp 1809 2008-02-24 05:16:03Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -31,7 +31,7 @@
 #endif
 
 #include "node.h"
-#include "nodebase.h"
+// #include "nodebase.h"		// this defines a bunch of sigc::slots that are never used
 
 #ifdef HASH_MAP_H
 #include HASH_MAP_H
