@@ -2,7 +2,7 @@
 /*!	\file value.h
 **	\brief Template Header
 **
-**	$Id: value.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -238,6 +238,10 @@ public:
 		{ return get(etl::loose_handle<Canvas>()); }
 	const char* get(const char*)const;
 	const list_type& get_list()const { return get(list_type()); }
+
+#ifdef _DEBUG
+	String get_string() const;
+#endif	// _DEBUG
 	// ========================================================================
 
 
@@ -320,7 +324,7 @@ public:
 
 	operator const list_type&()const { return get_list(); }
 	//operator const Color&()const { return get(Color()); }
-	//operator const Real&()const { return get(Real()); }
+	operator const Real&()const { return get(Real()); }
 	//operator const Time&()const { return get(Time()); }
 
 	operator const Vector&()const {  return get(Vector()); }
