@@ -2,7 +2,7 @@
 /*!	\file valuenode.cpp
 **	\brief Implementation of the "Placeholder" valuenode conversion.
 **
-**	$Id: valuenode.cpp 2095 2008-10-13 23:13:07Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,6 +45,7 @@
 #include "valuenode_linear.h"
 #include "valuenode_composite.h"
 #include "valuenode_reference.h"
+#include "valuenode_greyed.h"
 #include "valuenode_scale.h"
 #include "valuenode_blinecalctangent.h"
 #include "valuenode_blinecalcvertex.h"
@@ -85,6 +86,11 @@
 #include "valuenode_anglestring.h"
 #include "valuenode_intstring.h"
 #include "valuenode_log.h"
+#include "valuenode_pow.h"
+#include "valuenode_compare.h"
+#include "valuenode_not.h"
+#include "valuenode_and.h"
+#include "valuenode_or.h"
 
 #include "layer.h"
 
@@ -179,6 +185,13 @@ ValueNode::subsys_init()
 	ADD_VALUENODE(ValueNode_IntString,		  "intstring",		  _("Int String"),		 RELEASE_VERSION_0_61_09); // SVN r2010
 	ADD_VALUENODE(ValueNode_Logarithm,		  "logarithm",		  _("Logarithm"),		 RELEASE_VERSION_0_61_09); // SVN r2034
 
+	ADD_VALUENODE(ValueNode_Greyed,			  "greyed",			  _("Greyed"),			 RELEASE_VERSION_0_62_00); // SVN r2305
+	ADD_VALUENODE(ValueNode_Pow,		      "power",		      _("Power"),		     RELEASE_VERSION_0_62_00); // SVN r2362
+	ADD_VALUENODE(ValueNode_Compare,		  "compare",  	 	  _("Compare"),			 RELEASE_VERSION_0_62_00); // SVN r2364
+	ADD_VALUENODE(ValueNode_Not,		      "not",			  _("Not"),				 RELEASE_VERSION_0_62_00); // SVN r2364
+	ADD_VALUENODE(ValueNode_And,		      "and",			  _("And"),				 RELEASE_VERSION_0_62_00); // SVN r2364
+	ADD_VALUENODE(ValueNode_Or,		          "or",			  _("Or"),					 RELEASE_VERSION_0_62_00); // SVN r2364
+
 #undef ADD_VALUENODE
 #undef ADD_VALUENODE2
 
@@ -266,8 +279,23 @@ LinkableValueNode::set_link(int i,ValueNode::Handle x)
 
 	if(set_link_vfunc(i,x))
 	{
+		// Fix 2412072: remove the previous link from the parent_set unless one of the other links is also
+		// using it when we convert a value to 'switch', both 'on' and 'off' are linked to the same valuenode
+		// if we then disconnect one of the two, the one we disconnect is set to be a new valuenode_const
+		// and the previously shared value is removed from the parent set even though the other is still
+		// using it
 		if(previous)
-			remove_child(previous.get());
+		{
+			int size = link_count(), index;
+			for (index=0; index < size; ++index)
+			{
+				if (i == index) continue;
+				if (get_link(index) == previous)
+					break;
+			}
+			if (index == size)
+				remove_child(previous.get());
+		}
 		add_child(x.get());
 
 		if(!x->is_exported() && get_parent_canvas())
