@@ -2,7 +2,7 @@
 /*!	\file valuenode_const.cpp
 **	\brief Implementation of the "Constant" valuenode conversion.
 **
-**	$Id: valuenode_const.cpp 1193 2007-12-11 17:28:31Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -87,6 +87,9 @@ ValueNode_Const::~ValueNode_Const()
 ValueBase
 ValueNode_Const::operator()(Time /*t*/)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	return value;
 }
 
