@@ -2,7 +2,7 @@
 /*!	\file valuenode_gradientrotate.cpp
 **	\brief Implementation of the "Gradient Rotate" valuenode conversion.
 **
-**	$Id: valuenode_gradientrotate.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -91,6 +91,9 @@ synfig::ValueNode_GradientRotate::~ValueNode_GradientRotate()
 synfig::ValueBase
 synfig::ValueNode_GradientRotate::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	Gradient gradient;
 	gradient=(*ref_gradient)(t).get(gradient);
 	Real offset((*ref_offset)(t).get(Real()));
