@@ -2,7 +2,7 @@
 /*!	\file valuenode_linear.cpp
 **	\brief Implementation of the "Linear" valuenode conversion.
 **
-**	$Id: valuenode_linear.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -108,6 +108,9 @@ ValueNode_Linear::~ValueNode_Linear()
 ValueBase
 ValueNode_Linear::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	switch(get_type())
 	{
 	case ValueBase::TYPE_ANGLE:
