@@ -2,7 +2,7 @@
 /*!	\file valuenode_radialcomposite.cpp
 **	\brief Implementation of the "Radial Composite" valuenode conversion.
 **
-**	$Id: valuenode_radialcomposite.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -96,6 +96,9 @@ ValueNode_RadialComposite::create_new()const
 ValueBase
 synfig::ValueNode_RadialComposite::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	switch(get_type())
 	{
 		case ValueBase::TYPE_VECTOR:
