@@ -151,6 +151,9 @@ ValueNode_Reciprocal::get_link_index_from_name(const String &name)const
 ValueBase
 ValueNode_Reciprocal::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	Real link     = (*link_)    (t).get(Real());
 	Real epsilon  = (*epsilon_) (t).get(Real());
 	Real infinite = (*infinite_)(t).get(Real());
