@@ -2,7 +2,7 @@
 /*!	\file valuenode_reference.cpp
 **	\brief Implementation of the "Reference" valuenode conversion.
 **
-**	$Id: valuenode_reference.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -140,6 +140,9 @@ ValueNode_Reference::get_link_index_from_name(const String &name)const
 ValueBase
 ValueNode_Reference::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	return (*link_)(t);
 }
 
