@@ -2,7 +2,7 @@
 /*!	\file valuenode_repeat_gradient.cpp
 **	\brief Implementation of the "Repeat Gradient" valuenode conversion.
 **
-**	$Id: valuenode_repeat_gradient.cpp 604 2007-09-05 14:29:02Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -96,6 +96,9 @@ synfig::ValueNode_Repeat_Gradient::~ValueNode_Repeat_Gradient()
 synfig::ValueBase
 synfig::ValueNode_Repeat_Gradient::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	const int count((*count_)(t).get(int()));
 	int i;
 	Gradient ret;
