@@ -2,7 +2,7 @@
 /*!	\file valuenode_scale.h
 **	\brief Header file for implementation of the "Scale" valuenode conversion.
 **
-**	$Id: valuenode_scale.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -64,6 +64,12 @@ public:
 
 	virtual ValueBase operator()(Time t)const;
 
+	//! Returns the modified Link to match the target value at time t
+	ValueBase get_inverse(Time t, const synfig::Vector &target_value) const;
+	ValueBase get_inverse(Time t, const synfig::Angle &target_value) const;
+
+	bool is_invertible(Time t)const;
+
 	virtual String get_name()const;
 
 	virtual String get_local_name()const;
