@@ -2,7 +2,7 @@
 /*!	\file valuenode_segcalctangent.cpp
 **	\brief Implementation of the "Segment Tangent" valuenode conversion.
 **
-**	$Id: valuenode_segcalctangent.cpp 1857 2008-03-04 22:02:22Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -79,6 +79,9 @@ ValueNode_SegCalcTangent::~ValueNode_SegCalcTangent()
 ValueBase
 ValueNode_SegCalcTangent::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	Segment segment((*segment_)(t).get(Segment()));
 
 	etl::hermite<Vector> curve(segment.p1,segment.p2,segment.t1,segment.t2);
