@@ -2,7 +2,7 @@
 /*!	\file valuenode_sine.cpp
 **	\brief Implementation of the "Sine" valuenode conversion.
 **
-**	$Id: valuenode_sine.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -86,6 +86,9 @@ ValueNode_Sine::~ValueNode_Sine()
 ValueBase
 ValueNode_Sine::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	return
 		Angle::sin(
 			(*angle_)(t).get(Angle())
