@@ -2,7 +2,7 @@
 /*!	\file valuenode_subtract.cpp
 **	\brief Implementation of the "Subtract" valuenode conversion.
 **
-**	$Id: valuenode_subtract.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -125,6 +125,9 @@ synfig::ValueNode_Subtract::~ValueNode_Subtract()
 synfig::ValueBase
 synfig::ValueNode_Subtract::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	if(!ref_a || !ref_b)
 		throw runtime_error(strprintf("ValueNode_Subtract: %s",_("One or both of my parameters aren't set!")));
 	switch(get_type())
