@@ -3,9 +3,8 @@
 #OPTIONS="--disable-optimization --enable-debug"
 
 OPTIONS="--enable-optimization=1 --disable-debug"
-#OPTIONS="$OPTIONS --enable-timelimit=120"
 
-[ -e configure ] || ./bootstrap || exit 0
+[ -e configure ] || ( libtoolize --ltdl --copy --force && autoreconf --force --install ) || exit 0
 
 [ -d win32build ] && rm -fr win32build
 
